@@ -8,10 +8,8 @@ def tokenise(input_text: str):
     doc = nlp(input_text)
     result = []
     for sent_idx, sent in enumerate(doc.sents):
-        result.append({"new_sentence": sent_idx})
-
         for token in sent:
-            result.append((token.i, token.text.replace("\n", " "), token.idx, token.idx + len(token.text)))
+            result.append((token.i, sent_idx, token.text.replace("\n", " "), token.idx, token.idx + len(token.text)))
     return result
 
 
@@ -22,12 +20,9 @@ def main(in_file_path, output_folder_path):
     tokens = tokenise(input_text)
     out_file = open(join(output_folder_path, f"{input_filename}_tokenized.tsv"), "wt", encoding="utf-8")
     writer = csv.writer(out_file, delimiter="\t", lineterminator="\n")
-    writer.writerow(["id", "token", "start", "end"])
+    writer.writerow(["id", "sent_id", "token", "start", "end"])
     for token in tokens:
-        if 'new_sentence' in token:
-            writer.writerow([f"# new sentence id {token['new_sentence']}"])
-        else:
-            writer.writerow(token)
+        writer.writerow(token)
 
     out_file.close()
 
